@@ -2,7 +2,7 @@ package SQL::TwoWay;
 use strict;
 use warnings FATAL => 'recursion';
 use 5.010001; # Named capture
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 use Carp ();
 use Scalar::Util qw(reftype);
 
@@ -32,8 +32,8 @@ sub two_way_sql {
 
     my $tokens = tokenize_two_way_sql($sql);
     my $ast = parse_two_way_sql($tokens);
-    my ($sql, @binds) = process_two_way_sql($ast, $params);
-    return ($sql, @binds);
+    my ($generated_sql, @binds) = process_two_way_sql($ast, $params);
+    return ($generated_sql, @binds);
 }
 
 sub process_two_way_sql {
@@ -89,7 +89,11 @@ sub _parse_statements {
     my ($tokens) = @_;
 
     my @stmts;
-    while (@$tokens && $tokens->[0]->[0] ~~ [SQL, VARIABLE, IF]) {
+    while (@$tokens && (
+            $tokens->[0]->[0] == SQL
+        ||  $tokens->[0]->[0] == VARIABLE
+        ||  $tokens->[0]->[0] == IF
+    )) {
         push @stmts, _parse_stmt($tokens);
     }
     return \@stmts;
@@ -244,7 +248,7 @@ I guess building complex SQL using O/R Mapper or SQL builder, like SQL::Abstract
 When you writing complex SQL, you should write SQL by your hand.
 
 And then, you got a issue: "I can't run my query on MySQL console!". Yes.
-A query like "SELECT * FROM cd WHERE name=?" is not runnable on console because that contains placeholder.
+A query like C<< SELECT * FROM cd WHERE name=? >> is not runnable on console because that contains placeholder.
 
 So, the solution is SQL::TwoWay.
 
